@@ -13,8 +13,11 @@ class ScrapyItemU(scrapy.Item, PyApiB):
         return PyApiB._produce(key, __class__)
 
     saveTableName = None
-    """ 数据保存入库对应的表名，如果不指定，默认用类名 """
-
+    """ 数据保存入库对应的表名，如果不指定，默认用item的类名 """
+    
+    saveDbName = None
+    """ 数据保存入库对应的库名，如果不指定，默认用工程名 """
+    
     @staticmethod
     def normal():
         """
