@@ -3,9 +3,11 @@ from ..py_api_b import PyApiB
 import scrapy
 from ..py_crawl.scrapyItemU import ScrapyItemU
 from ..py_db.mongoDBU import MongoDBU
-from .chromeU import ChromeU
+from ..py_crawl.chromeU import ChromeU
 from scrapy.loader.processors import Identity, MapCompose
-from .scrapySaveItem import ScrapySaveItem
+from scrapy.loader import ItemLoader
+from scrapy.loader.processors import TakeFirst
+from ..py_crawl.scrapySaveItem import ScrapySaveItem
 
 
 class ScrapySpiderU(scrapy.Spider, PyApiB):
@@ -72,8 +74,6 @@ class ScrapySpiderU(scrapy.Spider, PyApiB):
         import random
         import string
         setattr(self,'saveSign',''.join(random.sample(string.ascii_letters + string.digits, 32)))
-        from scrapy.loader import ItemLoader
-        from scrapy.loader.processors import TakeFirst
         item_loader = ItemLoader(item=ScrapySaveItem())
         item_loader.default_output_processor = TakeFirst()
         item_loader.add_value('type','begin')
@@ -81,9 +81,7 @@ class ScrapySpiderU(scrapy.Spider, PyApiB):
         return item_loader.load_item()
     
     def saveCommit(self,optionType='insert'):
-        """ option=insert|upsert """
-        from scrapy.loader import ItemLoader
-        from scrapy.loader.processors import TakeFirst
+        """ option=insert|upsert|jsonfile@filePath """
         item_loader = ItemLoader(item=ScrapySaveItem())
         item_loader.default_output_processor = TakeFirst()
         item_loader.add_value('type','commit')
